**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name             modelEco_dairyFarm_1.gms
Sequence         2 - The farm model
GAMS language    subset, 3 input tables , indexed equations
Type             LP
Description
Mr. Quatresabots' dairy farm is located in western France.
It is a 50 ha farm 30 ha of which is arable land on which the farmer can grow wheat (for selling purposes) and/or maize silage (to feed his dairy cows),
and 20 ha is permanent grassland that cannot be tilled (CAP greening rules) and that is dedicated to grazing, as well as hay production and wrapped bales.
The cows graze for 6 months (early April - late September). During the winter period, they are fed on maize silage (produced on the farm)
and supplemented with soya-bean concentrates and cakes (purchased).
The young heifers are fed by grazing, hay and wrapped bales.
For dairy cows, the farmer can slightly vary the ratio between grazing and supplements. Two diets are therefore defined: the "grass-based" diet (H);
in which the share of pasture in relation to maize and soya is higher; and a diet called "intensive" (I) in which the share of soya and maize is increased.
The first diet allows an average production of 7000 litres (L) per dairy cow per year;
the second one generates a slightly higher production of 7140 L
Statement see http://www.supagro.fr/wordpress/modelecoen/auto-formation/sequence2/cours2-des-specificites-du-modele-agricole/lecon-15-l-elevage/activite-15-exploitation-laitiere/


$offtext

*-----------------------------------------------------------------------------*


*----------                          DECLARATION                    ----------*


SET
A     cattle present (dairy cow heifer and calf)                                  /DC,Heif,calf/
C     crops                                                                       /wheat,maize,grassland/
CA(C) annual crops                                                                /wheat, maize/
F     fodder produced ("silage maize" "hay" "wrapped bales" and "grazing" )       /sillage,hay,wrapp,grazing/
CP    concentrate feed purchased                                                  /soybean/
R     Diet                                                                        /I,H/

SCALARS

Land_AC  land availability (crops)       /30/
pg       permanent grasslands            /20/
QUO      available quota                 /300000/
Cull     Culling rate                    /0.3/
PROL     prolificacy per Dairy cow       /0.9/
PcMilk   milk price in euros per litre   /0.35/
RTsold   rate of calves sold             /0.6/

PARAMETER
PriceC(C)    price of sales crops in euros per tonne      /wheat 150/
cost(C)      costs per crop in euors per ha               /wheat 600,maize 620,grassland 300/
YieldS(C)    yields of sales crop in tonnes per ha        /wheat 6/
CostCon(CP)  cost of concentrate in euros per tonne       /soybean 360/

parameter GMc(c);
GMc(c)=PriceC(c)*YieldS(c)-cost(c);

TABLE
FYields(C,F) forage yields in tonnes per ha
          sillage    hay    wrapp   grazing
maize       11
grassland            4.5     2.2      5

TABLE
AFR(A,R,F) animal forage requirements in tonnes per animal
           sillage    hay    wrapp   grazing
DC.I         2                          1
Heif.I                 2       2.6      2.5

DC.H         1                          1.5
Heif.H                 2       2.6      2.5

TABLE
ACR(A,R,CP)  animal concentrate requirements in tonnes per animal
             soybean
DC.I         0.57
DC.H         0.45
;


PARAMETER
PriceA(A)   selling price in euros per animal    /DC 800, calf 170/
PL(A,R)     productivity in litres per DC        /DC.I 7140, DC.H 7000/
OPcost(A)   fixed and operating costs            /DC 1300/

parameter feedcost,feedcostl;
feedcost(A,R)=sum(cp,ACR(A,R,CP)*CostCon(CP));

*----------                          MODEL                         ----------*

VARIABLES
Z
X(C)
N(A, R)
;

positive variables
X,N
;

Equations
Objective        objective function
Quota            quota equation
Land             area restriction for cultivated land
PGrassland       area restriction for permanent grasslands
Feed(F)          Feed equation
DemCC            demographic equation (culled cows)
Demog            demographic equation

;

Objective..       Z =e= sum(c,X(c)*GMc(C))+sum((A,R),N(A,R)*PL(A,R)*PcMilk)
                  +sum(R,N('calf',R)*PriceA('calf'))
                  +sum(R,N('DC',R)*Cull*PriceA('DC') )
                  -sum((A,R),N(A,R)*feedcost(A,R))
                  -sum((A,R),N(A,R)*OPcost(A))
;
Quota..           sum((A,R),N(A,R)*PL(A,R)) =l= QUO;
Land..            sum(ca,X(ca)) =l= Land_AC;
PGrassland..      x('grassland')=l=pg;
Feed(F)..         sum((A,R),N(A,R)*AFR(A,R,F)) =l= sum(C,X(C)*FYields(C,F));
DemCC(R)..        N('Heif',R) =e= N('DC',R)*Cull;
Demog(R)..        N('calf',R)+N('Heif',R) =e= N('DC',R)*prol;

model milk /all/;

*----------                        SOLUTION                         ----------*

parameter result ;

solve milk using LP maximizing Z;

result("QUO","")=QUO;
result("PcMilk","")=PcMilk;
result(A,R)=N.l(A,R);
result(C,"")=X.l(C);
result("income","")=Z.l;
result("prodmilk","")=sum((A,R),N.l(A,R)*PL(A,R));

display result ;

